Module: ControllerMethods::InstanceMethods
- Defined in:
- lib/sessionvoc-store/open/controller_methods.rb
Instance Method Summary collapse
-
#init_sessionvoc ⇒ Object
Workaround used to create a new rack session because rack sessions are being created lazily and the usage of some of the sessionvoc methods might fail if no rack session exists.
Instance Method Details
#init_sessionvoc ⇒ Object
Workaround used to create a new rack session because rack sessions are being created lazily and the usage of some of the sessionvoc methods might fail if no rack session exists.
6 7 8 |
# File 'lib/sessionvoc-store/open/controller_methods.rb', line 6 def init_sessionvoc session['sessionvoc-init'] = true end |